# Casing Dictionary Explanation

The `casing_dict` is a dictionary used in the `transpile_to_html` function to map node names to corresponding HTML tags. Each key-value pair in the dictionary represents a mapping from a node name to its corresponding HTML tag.

Here is an explanation of the purpose of each key-value pair in the `casing_dict`:

- `"Container": "div"`: Represents a container element, which is typically represented by a `<div>` tag in HTML.
- `"Header": "h1"`: Represents a header element, typically represented by an `<h1>` tag.
- `"Block": "div"`: Represents a block element, often represented by a `<div>` tag.
- `"Button": "button"`: Represents a button element, typically represented by a `<button>` tag.
- `"Paragraph": "p"`: Represents a paragraph element, typically represented by a `<p>` tag.
- `"Span": "span"`: Represents a span element, typically represented by a `<span>` tag.
- `"Image": "img"`: Represents an image element, typically represented by an `<img>` tag.
- `"Link": "a"`: Represents a link element, typically represented by an `<a>` tag.
- `"List": "ul"`: Represents a list element, typically represented by a `<ul>` tag.
- `"ListItem": "li"`: Represents a list item element, typically represented by a `<li>` tag.
- `"Input": "input"`: Represents an input element, typically represented by an `<input>` tag.
- `"Label": "label"`: Represents a label element, typically represented by a `<label>` tag.
- `"Form": "form"`: Represents a form element, typically represented by a `<form>` tag.
- `"Table": "table"`: Represents a table element, typically represented by a `<table>` tag.
- `"TableHeader": "th"`: Represents a table header element, typically represented by a `<th>` tag.
- `"TableRow": "tr"`: Represents a table row element, typically represented by a `<tr>` tag.
- `"TableData": "td"`: Represents a table data element, typically represented by a `<td>` tag.
- `"Select": "select"`: Represents a select element, typically represented by a `<select>` tag.
- `"Option": "option"`: Represents an option element, typically represented by an `<option>` tag.
- `"Nav": "nav"`: Represents a navigation element, typically represented by a `<nav>` tag.
- `"Section": "section"`: Represents a section element, typically represented by a `<section>` tag.
- `"Article": "article"`: Represents an article element, typically represented by an `<article>` tag.
- `"Footer": "footer"`: Represents a footer element, typically represented by a `<footer>` tag.
- `"Header1": "h1"`: Represents a header 1 element, typically represented by an `<h1>` tag.
- `"Header2": "h2"`: Represents a header 2 element, typically represented by an `<h2>` tag.
- `"Header3": "h3"`: Represents a header 3 element, typically represented by an `<h3>` tag.
- `"Header4": "h4"`: Represents a header 4 element, typically represented by an `<h4>` tag.
- `"Header5": "h5"`: Represents a header 5 element, typically represented by an `<h5>` tag.
- `"Header6": "h6"`: Represents a header 6 element, typically represented by an `<h6>` tag.
- `"Strong": "strong"`: Represents a strong element, typically represented by a `<strong>` tag.
- `"Emphasis": "em"`: Represents an emphasis element, typically represented by an `<em>` tag.
- `"Div": "div"`: Represents a div element, typically represented by a `<div>` tag.
- `"Small": "small"`: Represents a small element, typically represented by a `<small>` tag.
- `"Pre": "pre"`: Represents a preformatted element, typically represented by a `<pre>` tag.
- `"Code": "code"`: Represents a code element, typically represented by a `<code>` tag.
- `"Blockquote": "blockquote"`: Represents a blockquote element, typically represented by a `<blockquote>` tag.
- `"Iframe": "iframe"`: Represents an iframe element, typically represented by an `<iframe>` tag.
- `"Audio": "audio"`: Represents an audio element, typically represented by an `<audio>` tag.
- `"Video": "video"`: Represents a video element, typically represented by a `<video>` tag.
- `"Source": "source"`: Represents a source element, typically represented by a `<source>` tag.
- `"Canvas": "canvas"`: Represents a canvas element, typically represented by a `<canvas>` tag.
- `"HeaderGroup": "thead"`: Represents a table header group element, typically represented by a `<thead>` tag.
- `"BodyGroup": "tbody"`: Represents a table body group element, typically represented by a `<tbody>` tag.
- `"FooterGroup": "tfoot"`: Represents a table footer group element, typically represented by a `<tfoot>` tag.
- `"ListOrdered": "ol"`: Represents an ordered list element, typically represented by an `<ol>` tag.
- `"DefinitionList": "dl"`: Represents a definition list element, typically represented by a `<dl>` tag.
- `"DefinitionTerm": "dt"`: Represents a definition term element, typically represented by a `<dt>` tag.
- `"DefinitionDescription": "dd"`: Represents a definition description element, typically represented by a `<dd>` tag.
- `"Figure": "figure"`: Represents a figure element, typically represented by a `<figure>` tag.
- `"FigCaption": "figcaption"`: Represents a figure caption element, typically represented by a `<figcaption>` tag.
- `"Progress": "progress"`: Represents a progress element, typically represented by a `<progress>` tag.
- `"Meter": "meter"`: Represents a meter element, typically represented by a `<meter>` tag.
- `"Time": "time"`: Represents a time element, typically represented by a `<time>` tag.
- `"Mark": "mark"`: Represents a mark element, typically represented by a `<mark>` tag.
- `"Ruby": "ruby"`: Represents a ruby element, typically represented by a `<ruby>` tag.
- `"RubyText": "rt"`: Represents a ruby text element, typically represented by an `<rt>` tag.
- `"RubyParenthesis": "rp"`: Represents a ruby parenthesis element, typically represented by an `<rp>` tag.
- `"Details": "details"`: Represents a details element, typically represented by a `<details>` tag.
- `"Summary": "summary"`: Represents a summary element, typically represented by a `<summary>` tag.
- `"Command": "command"`: Represents a command element, typically represented by a `<command>` tag.
- `"Menu": "menu"`: Represents a menu element, typically represented by a `<menu>` tag.
- `"Dialog": "dialog"`: Represents a dialog element, typically represented by a `<dialog>` tag.
- `"Slot": "slot"`: Represents a slot element, typically represented by a `<slot>` tag.
- `"Template": "template"`: Represents a template element, typically represented by a `<template>` tag.
- `"Slotable": "slot"`: Represents a slotable element, typically represented by a `<slot>` tag.
- `"Shadow": "shadow"`: Represents a shadow element, typically represented by a `<shadow>` tag.
- `"Keygen": "keygen"`: Represents a keygen element, typically represented by a `<keygen>` tag.
- `"Main": "main"`: Represents a main element, typically represented by a `<main>` tag.
- `"Math": "math"`: Represents a math element, typically represented by a `<math>` tag.
- `"Svg": "svg"`: Represents an SVG element, typically represented by an `<svg>` tag.
- `"ForeignObject": "foreignObject"`: Represents a foreign object element, typically represented by a `<foreignObject>` tag.
- `"Animation": "animate"`: Represents an animation element, typically represented by an `<animate>` tag.
- `"Set": "set"`: Represents a set element, typically represented by a `<set>` tag.
- `"Group": "g"`: Represents a group element, typically represented by a `<g>` tag.
- `"Path": "path"`: Represents a path element, typically represented by a `<path>` tag.
- `"Polygon": "polygon"`: Represents a polygon element, typically represented by a `<polygon>` tag.
- `"Polyline": "polyline"`: Represents a polyline element, typically represented by a `<polyline>` tag.
- `"Circle": "circle"`: Represents a circle element, typically represented by a `<circle>` tag.
- `"Ellipse": "ellipse"`: Represents an ellipse element, typically represented by an `<ellipse>` tag.
- `"Rect": "rect"`: Represents a rectangle element, typically represented by a `<rect>` tag.
- `"Line": "line"`: Represents a line element, typically represented by a `<line>` tag.
- `"Text": "text"`: Represents a text element, typically represented by a `<text>` tag.
- `"Tspan": "tspan"`: Represents a text span element, typically represented by a `<tspan>` tag.
- `"TextPath": "textPath"`: Represents a text path element, typically represented by a `<textPath>` tag.
- `"Use": "use"`: Represents a use element, typically represented by a `<use>` tag.
- `"Defs": "defs"`: Represents a defs element, typically represented by a `<defs>` tag.
- `"Pattern": "pattern"`: Represents a pattern element, typically represented by a `<pattern>` tag.
- `"LinearGradient": "linearGradient"`: Represents a linear gradient element, typically represented by a `<linearGradient>` tag.
- `"RadialGradient": "radialGradient"`: Represents a radial gradient element, typically represented by a `<radialGradient>` tag.
- `"Stop": "stop"`: Represents a stop element, typically represented by a `<stop>` tag.
- `"Filter": "filter"`: Represents a filter element, typically represented by a `<filter>` tag.
- `"FeBlend": "feBlend"`: Represents a feBlend element, typically represented by a `<feBlend>` tag.
- `"FeColorMatrix": "feColorMatrix"`: Represents a feColorMatrix element, typically represented by a `<feColorMatrix>` tag.
- `"FeComponentTransfer": "feComponentTransfer"`: Represents a feComponentTransfer element, typically represented by a `<feComponentTransfer>` tag.
- `"FeComposite": "feComposite"`: Represents a feComposite element, typically represented by a `<feComposite>` tag.
- `"FeConvolveMatrix": "feConvolveMatrix"`: Represents a feConvolveMatrix element, typically represented by a `<feConvolveMatrix>` tag.
- `"FeDiffuseLighting": "feDiffuseLighting"`: Represents a feDiffuseLighting element, typically represented by a `<feDiffuseLighting>` tag.
- `"FeDisplacementMap": "feDisplacementMap"`: Represents a feDisplacementMap element, typically represented by a `<feDisplacementMap>` tag.
- `"FeDistantLight": "feDistantLight"`: Represents a feDistantLight element, typically represented by a `<feDistantLight>` tag.
- `"FeFlood": "feFlood"`: Represents a feFlood element, typically represented by a `<feFlood>` tag.
- `"FeGaussianBlur": "feGaussianBlur"`: Represents a feGaussianBlur element, typically represented by a `<feGaussianBlur>` tag.
- `"FeImage": "feImage"`: Represents a feImage element, typically represented by a `<feImage>` tag.
- `"FeMerge": "feMerge"`: Represents a feMerge element, typically represented by a `<feMerge>` tag.
- `"FeMorphology": "feMorphology"`: Represents a feMorphology element, typically represented by a `<feMorphology>` tag.
- `"FeOffset": "feOffset"`: Represents a feOffset element, typically represented by a `<feOffset>` tag.
- `"FePointLight": "fePointLight"`: Represents a fePointLight element, typically represented by a `<fePointLight>` tag.
- `"FeSpecularLighting": "feSpecularLighting"`: Represents a feSpecularLighting element, typically represented by a `<feSpecularLighting>` tag.
- `"FeSpotLight": "feSpotLight"`: Represents a feSpotLight element, typically represented by a `<feSpotLight>` tag.
- `"FeTile": "feTile"`: Represents a feTile element, typically represented by a `<feTile>` tag.
- `"FeTurbulence": "feTurbulence"`: Represents a feTurbulence element, typically represented by a `<feTurbulence>` tag.
- `"FeDx": "feDx"`: Represents a feDx element, typically represented by a `<feDx>` tag.
- `"FeDy": "feDy"`: Represents a feDy element, typically represented by a `<feDy>` tag.
- `"FeWidth": "feWidth"`: Represents a feWidth element, typically represented by a `<feWidth>` tag.
- `"FeHeight": "feHeight"`: Represents a feHeight element, typically represented by a `<feHeight>` tag.
- `"ForeignObject": "foreignObject"`: Represents a foreign object element, typically represented by a `<foreignObject>` tag.
- `"AnimateTransform": "animateTransform"`: Represents an animate transform element, typically represented by an `<animateTransform>` tag.
- `"AnimateMotion": "animateMotion"`: Represents an animate motion element, typically represented by an `<animateMotion>` tag.
- `"AnimateColor": "animateColor"`: Represents an animate color element, typically represented by an `<animateColor>` tag.
- `"Animate": "animate"`: Represents an animate element, typically represented by an `<animate>` tag.
- `"SolidColor": "solidColor"`: Represents a solid color element, typically represented by a `<solidColor>` tag.
- `"FontFace": "font-face"`: Represents a font face element, typically represented by a `<font-face>` tag.
- `"Glyph": "glyph"`: Represents a glyph element, typically represented by a `<glyph>` tag.
- `"MissingGlyph": "missing-glyph"`: Represents a missing glyph element, typically represented by a `<missing-glyph>` tag.
- `"Font": "font"`: Represents a font element, typically represented by a `<font>` tag.
- `"FontFaceSrc": "src"`: Represents a font face source element, typically represented by a `<src>` tag.
- `"FontFaceUri": "uri"`: Represents a font face URI element, typically represented by a `<uri>` tag.
- `"FontFaceFormat": "format"`: Represents a font face format element, typically represented by a `<format>` tag.
- `"FontFaceName": "name"`: Represents a font face name element, typically represented by a `<name>` tag.
- `"Kbd": "kbd"`: Represents a keyboard input element, typically represented by a `<kbd>` tag.
- `"Samp": "samp"`: Represents a sample output element, typically represented by a `<samp>` tag.
- `"Var": "var"`: Represents a variable element, typically represented by a `<var>` tag.
- `"Bdo": "bdo"`: Represents a bidirectional override element, typically represented by a `<bdo>` tag.
- `"Wbr": "wbr"`: Represents a word break opportunity element, typically represented by a `<wbr>` tag.
- `"Ins": "ins"`: Represents an inserted text element, typically represented by an `<ins>` tag.
- `"Del": "del"`: Represents a deleted text element, typically represented by a `<del>` tag.
- `"NoScript": "noscript"`: Represents a noscript element, typically represented by a `<noscript>` tag.
- `"Noscript": "noscript"`: Represents a noscript element, typically represented by a `<noscript>` tag.
- `"Section": "section"`: Represents a section element, typically represented by a `<section>` tag.
